@@ -64,17 +64,20 @@ def predict_model(config: dict, fun_control: dict) -> Tuple[float, float]:
     # the config id is generated here without a timestamp. This differs from
     # the config id generated in cvmodel.py and trainmodel.py.
     config_id = generate_config_id(config, timestamp=False) + "_TEST"
-    dm = LightDataModule(
-        dataset=fun_control["data_set"],
-        data_full_train=fun_control["data_full_train"],
-        data_test=fun_control["data_test"],
-        batch_size=config["batch_size"],
-        num_workers=fun_control["num_workers"],
-        test_size=fun_control["test_size"],
-        test_seed=fun_control["test_seed"],
-        scaler=fun_control["scaler"],
-        verbosity=fun_control["verbosity"],
-    )
+    if fun_control["data_module"] is None:
+        dm = LightDataModule(
+            dataset=fun_control["data_set"],
+            data_full_train=fun_control["data_full_train"],
+            data_test=fun_control["data_test"],
+            batch_size=config["batch_size"],
+            num_workers=fun_control["num_workers"],
+            test_size=fun_control["test_size"],
+            test_seed=fun_control["test_seed"],
+            scaler=fun_control["scaler"],
+            verbosity=fun_control["verbosity"],
+        )
+    else:
+        dm = fun_control["data_module"]
     # TODO: Check if this is necessary:
     # dm.setup(stage="train")
     # Init model from datamodule's attributes
@@ -104,9 +107,12 @@ def predict_model(config: dict, fun_control: dict) -> Tuple[float, float]:
     # Pass the datamodule as arg to trainer.fit to override model hooks :)
     trainer.fit(model=model, datamodule=dm)
 
-    dm.setup(stage="predict")
-    predictions = trainer.predict(model=model, datamodule=dm)
-    # predictions = trainer.predict(datamodule=dm)
+    # Changed in spotpython 0.18.12: commented out the following line
+    # dm.setup(stage="predict")
+
+    # predictions = trainer.predict(model=model, datamodule=dm)
+    # Changed in spotpython 0.18.12: use ckpt_path="last" to load the last checkpoint and not the model
+    predictions = trainer.predict(datamodule=dm, ckpt_path="last")
 
     # # Load the last checkpoint
     # test_result = trainer.test(datamodule=dm, ckpt_path="last")
